@@ -1,6 +1,6 @@
 import logging
 from dataclasses import dataclass, field
-from typing import Type
+from typing import Type, Self
 
 from dict_caster.extras import to_list
 
@@ -17,8 +17,8 @@ logger = logging.getLogger(__name__)
 
 
 @dataclass
-class Select(AbstractStatement):
-    table: Type[Table]
+class Select(AbstractStatement, Sqlable):
+    select_from: Type[Table] | Self
     selectables: list[Selectable] | Selectable | None = field(default_factory=list)
     condition: Condition.get_condition_type() | None = None
     group_by: list[Sqlable] | Sqlable | None = field(default_factory=list)
@@ -36,9 +36,20 @@ class Select(AbstractStatement):
         self.distinct_on = to_list(self.distinct_on) if self.distinct_on is not None else []
         self.group_by = to_list(self.group_by) if self.group_by is not None else []
         self.order_by = to_list(self.order_by) if self.order_by is not None else []
+    def to_sql(self) -> str:
+        return self.generate_sql()
+
+    @property
+    def table(self):
+        if issubclass(self.select_from, Table):
+            return self.select_from
+        elif issubclass(self.select_from, Select):
+            return self.select_from.table
+        else:
+            raise ValueError(f'unexpected {self.select_from=}')
 
     def generate_sql(self):
-        table_name = self.table.get_name()
+
         select_sql = self._construct_select_sql()
         distinct_on_sql = self._construct_distinct_on_sql()
         where_sql = self._construct_where_sql()
@@ -46,7 +57,7 @@ class Select(AbstractStatement):
         order_sql = self._construct_order_sql()
         limit_sql = self._construct_limit_sql()
         offset_sql =self._construct_offset_sql()
-        sql = f"SELECT {distinct_on_sql} {select_sql} FROM {table_name} {where_sql} {group_sql} {order_sql} {limit_sql} {offset_sql}"
+        sql = f"SELECT {distinct_on_sql} {select_sql} FROM {self.select_from.to_sql()} {where_sql} {group_sql} {order_sql} {limit_sql} {offset_sql}"
         logger.debug(f"constructed {sql=}")
         return sql
 
